==> hyades.source_1.0.3_20030929_1406.zip: org/eclipse/hyades/test/ui/internal/editor/form/base/SharedPartWithButtons.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.ui.internal.editor.form.base;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Menu;

/**
 * @author marcelop
 * @since 0.2.0
 */
public abstract class SharedPartWithButtons 
extends SharedPart
{
	private String[] buttonLabels;
	private Control[] controls;
	private Composite buttonContainer;

	private class SelectionHandler implements SelectionListener
	{
		public void widgetSelected(SelectionEvent e)
		{
			buttonSelected(e);
		}
		public void widgetDefaultSelected(SelectionEvent e)
		{
			buttonSelected(e);
		}
		private void buttonSelected(SelectionEvent e)
		{
			Integer index = (Integer)e.widget.getData();
			SharedPartWithButtons.this.buttonSelected((Button)e.widget, index.intValue());
		}
	}

	public SharedPartWithButtons(String[] buttonLabels)
	{
		this.buttonLabels = buttonLabels;
	}

	public void setButtonEnabled(int index, boolean enabled)
	{
		if (controls != null && index >= 0 && controls.length > index)
		{
			Control c = controls[index];
			if (c instanceof Button)
				c.setEnabled(enabled);
		}
	}
	
	public String getButtonLabel(int index)
	{
		return buttonLabels[index];
	}
	
	public Menu getButtonMenu(int index)
	{
		if(controls[index].getMenu() == null)
			controls[index].setMenu(new Menu(controls[index]));
		return controls[index].getMenu();
	}

	protected abstract void createMainControl(Composite parent, int style, int span, FormWidgetFactory factory);
	protected abstract void buttonSelected(Button button, int index);

	/*
	 * @see SharedPart#createControl(Composite, FormWidgetFactory)
	 */
	public void createControl(Composite parent, int style, int span, FormWidgetFactory factory)
	{
		createMainLabel(parent, span, factory);
		createMainControl(parent, style, span - 1, factory);
		if (buttonLabels != null && buttonLabels.length > 0)
		{
			buttonContainer = createComposite(parent, factory);
			GridData gd = new GridData(GridData.FILL_VERTICAL);
			buttonContainer.setLayoutData(gd);
			buttonContainer.setLayout(createButtonsLayout());

			controls = new Control[buttonLabels.length];
			SelectionHandler listener = new SelectionHandler();
			for (int i = 0; i < buttonLabels.length; i++)
			{
				String label = buttonLabels[i];
				if (label != null)
				{
					Button button = createButton(buttonContainer, label, i, factory);
					button.addSelectionListener(listener);
					controls[i] = button;
				}
				else
				{
					createEmptySpace(buttonContainer, 1, factory);
				}
			}
		}
	}

	protected GridLayout createButtonsLayout()
	{
		GridLayout layout = new GridLayout();
		layout.marginWidth = layout.marginHeight = 0;
		return layout;
	}

	protected Button createButton(Composite parent, String label, int index, FormWidgetFactory factory)
	{
		Button button;

		if (factory != null)
			button = factory.createButton(parent, label, SWT.PUSH);
		else
		{
			button = new Button(parent, SWT.PUSH);
			button.setText(label);
		}
		GridData gd = new GridData(GridData.FILL_HORIZONTAL | GridData.VERTICAL_ALIGN_BEGINNING);
		button.setLayoutData(gd);
		button.setData(new Integer(index));
		return button;
	}

	protected void updateEnabledState()
	{
		for (int i = 0; i < controls.length; i++)
		{
			Control c = controls[i];
			if (c instanceof Button)
				c.setEnabled(isEnabled());
		}
	}

	protected void createMainLabel(Composite parent, int span, FormWidgetFactory factory)
	{
	}
}

==> hyades.source_3.3.0_20050623_2150.zip: org/eclipse/hyades/test/ui/internal/editor/form/base/SharedPartWithButtons.java <==
/*******************************************************************************
 * Copyright (c) 2005 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * $Id: SharedPartWithButtons.java,v 1.5 2005/03/15 14:52:11 dguilbaud Exp $
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.ui.internal.editor.form.base;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Menu;

/**
 * @author marcelop
 * @since 0.2.0
 */
public abstract class SharedPartWithButtons 
extends SharedPart
{
	private String[] buttonLabels;
	private String[] toolTips;
	private Control[] controls;
	private Composite buttonContainer;

	private class SelectionHandler implements SelectionListener
	{
		public void widgetSelected(SelectionEvent e)
		{
			buttonSelected(e);
		}
		public void widgetDefaultSelected(SelectionEvent e)
		{
			buttonSelected(e);
		}
		private void buttonSelected(SelectionEvent e)
		{
			Integer index = (Integer)e.widget.getData();
			SharedPartWithButtons.this.buttonSelected((Button)e.widget, index.intValue());
		}
	}

	public SharedPartWithButtons(String[] buttonLabels)
	{
		this.buttonLabels = buttonLabels;
	}
	
	public SharedPartWithButtons(String[] buttonLabels,String[] toolTips)
	{
		this.buttonLabels = buttonLabels;
		this.toolTips = toolTips;
	}

	public void setButtonEnabled(int index, boolean enabled)
	{
		if (controls != null && index >= 0 && controls.length > index)
		{
			Control c = controls[index];
			if (c instanceof Button)
				c.setEnabled(enabled);
		}
	}
	
	public String getButtonLabel(int index)
	{
		return buttonLabels[index];
	}
	
	public Menu getButtonMenu(int index)
	{
		if(controls[index].getMenu() == null)
			controls[index].setMenu(new Menu(controls[index]));
		return controls[index].getMenu();
	}

	protected abstract void createMainControl(Composite parent, int style, int span, FormWidgetFactory factory);
	protected abstract void buttonSelected(Button button, int index);

	/*
	 * @see SharedPart#createControl(Composite, FormWidgetFactory)
	 */
	public void createControl(Composite parent, int style, int span, FormWidgetFactory factory)
	{
		createMainLabel(parent, span, factory);
		createMainControl(parent, style, span - 1, factory);
		if (buttonLabels != null && buttonLabels.length > 0)
		{
			buttonContainer = createComposite(parent, factory);
			GridData gd = new GridData(GridData.FILL_VERTICAL);
			buttonContainer.setLayoutData(gd);
			buttonContainer.setLayout(createButtonsLayout());

			controls = new Control[buttonLabels.length];
			SelectionHandler listener = new SelectionHandler();
			for (int i = 0; i < buttonLabels.length; i++)
			{
				String label = buttonLabels[i];
				if (label != null)
				{
					Button button = createButton(buttonContainer, label, i, factory);
					button.addSelectionListener(listener);
					if ((toolTips!=null) && (toolTips.length > i)) {
						button.setToolTipText(toolTips[i]);
					}
					
					controls[i] = button;
				}
				else
				{
					createEmptySpace(buttonContainer, 1, factory);
				}
			}
		}
	}

	protected GridLayout createButtonsLayout()
	{
		GridLayout layout = new GridLayout();
		layout.marginWidth = layout.marginHeight = 0;
		return layout;
	}

	protected Button createButton(Composite parent, String label, int index, FormWidgetFactory factory)
	{
		Button button;

		if (factory != null)
			button = factory.createButton(parent, label, SWT.PUSH);
		else
		{
			button = new Button(parent, SWT.PUSH);
			button.setText(label);
		}
		GridData gd = new GridData(GridData.FILL_HORIZONTAL | GridData.VERTICAL_ALIGN_BEGINNING);
		button.setLayoutData(gd);
		button.setData(new Integer(index));
		return button;
	}

	protected void updateEnabledState()
	{
		for (int i = 0; i < controls.length; i++)
		{
			Control c = controls[i];
			if (c instanceof Button)
				c.setEnabled(isEnabled());
		}
	}

	protected void createMainLabel(Composite parent, int span, FormWidgetFactory factory)
	{
	}
}
